@@ -1,5 +1,9 @@
 package GFtk;
-
+   use strict;
+   use warnings;
+   
+   our $VERSION = '0.061';
+   
    use parent qw(Tk::MainWindow);
    
    use Tk::JPEG;
