@@ -3,7 +3,7 @@ package GUIDeFATE;
    use strict;
    use warnings;
    
-   our $VERSION = '0.06';
+   our $VERSION = '0.061';
    
    use Exporter 'import';
    
@@ -190,6 +190,7 @@ sub convert{
 }
 
 1;
+
 =head1 GUIDeFATE
 
 GUIDeFATE  -  Graphical User Interface Design From A Text Editor
@@ -229,9 +230,10 @@ $frame
 
 =head1 DESCRIPTION
 
-GUIDeFATE enables the user to convert a textual representtaion into a Graphical user Interface
-It attempts to abstract out the underlying framework.  A visually recognisable pattern is passed
-as a string to GUIDeFATE and this is transformed into an Interactive Interface.
+GUIDeFATE enables the user to convert a textual representtaion into a
+Graphical user Interfac. It attempts to abstract out the underlying
+framework.  A visually recognisable pattern is passed as a string to
+GUIDeFATE and this is transformed into an Interactive Interface.
 
 =head1 METHODS
 
@@ -241,11 +243,17 @@ as a string to GUIDeFATE and this is transformed into an Interactive Interface.
 
 =item my $gui=GUIDeFATE->new($window, $backend, $options);
 
-Extracts dimensions and wdigets in a window from the textual representation
+Extracts dimensions and wdigets in a window from the textual
+representation.
+If $options not pprovided, defaults to "Wx"; options are Wx and Tk.
+If $options contains "v", then a verbose output is sent to console,
+if it contains "a", and autogenerated file is produced with all the
+called functions
 
 =item my $frame=$gui->getFrame;
 
-Returns reference to the frame for both abstracted and backend specific functions 
+Returns reference to the frame for both abstracted and backend
+specific functions.
 
 =back
 
